@@ -138,12 +138,9 @@ class IotToLambda(
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
-        access:
-        :access:: public
-        since:
-        :since:: 0.8.0
-        summary:
-        :summary:: Constructs a new instance of the IotToLambda class.
+        :access: public
+        :since: 0.8.0
+        :summary: Constructs a new instance of the IotToLambda class.
         """
         props = IotToLambdaProps(
             iot_topic_rule_props=iot_topic_rule_props,
@@ -186,8 +183,7 @@ class IotToLambdaProps:
         :param existing_lambda_obj: Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored. Default: - None
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
 
-        summary:
-        :summary:: The properties for the IotToLambda class.
+        :summary: The properties for the IotToLambda class.
         """
         if isinstance(iot_topic_rule_props, dict):
             iot_topic_rule_props = aws_cdk.aws_iot.CfnTopicRuleProps(**iot_topic_rule_props)
@@ -205,7 +201,6 @@ class IotToLambdaProps:
     def iot_topic_rule_props(self) -> aws_cdk.aws_iot.CfnTopicRuleProps:
         """User provided CfnTopicRuleProps to override the defaults.
 
-        default
         :default: - None
         """
         result = self._values.get("iot_topic_rule_props")
@@ -216,7 +211,6 @@ class IotToLambdaProps:
     def existing_lambda_obj(self) -> typing.Optional[aws_cdk.aws_lambda.Function]:
         """Existing instance of Lambda Function object, if this is set then the lambdaFunctionProps is ignored.
 
-        default
         :default: - None
         """
         result = self._values.get("existing_lambda_obj")
@@ -228,7 +222,6 @@ class IotToLambdaProps:
     ) -> typing.Optional[aws_cdk.aws_lambda.FunctionProps]:
         """User provided props to override the default props for the Lambda function.
 
-        default
         :default: - Default props are used
         """
         result = self._values.get("lambda_function_props")
